@@ -1,5 +1,5 @@
-use clap::Clap;
 use ansi_term::Colour;
+use clap::Clap;
 
 use anyhow::{anyhow, Context};
 use dialoguer::Select;
@@ -25,12 +25,16 @@ struct Rename {
 }
 
 #[derive(Clap)]
-#[clap(version = "1.2", author = "Marcus B. <me@mbufett.com>", about = "https://github.com/marcusbuffett/pipe-rename")]
+#[clap(
+    version = "1.2",
+    author = "Marcus B. <me@mbufett.com>",
+    about = "https://github.com/marcusbuffett/pipe-rename"
+)]
 struct Opts {
     #[clap(name = "FILES")]
     files: Vec<String>,
     /// Optionally set a custom rename command, like 'git mv'
-    #[clap(short, long)]
+    #[clap(short = 'c', long)]
     rename_command: Option<String>,
     /// Prettify diffs
     #[clap(short, long)]
@@ -53,10 +57,10 @@ impl Rename {
                     match change {
                         TextDiff::Removed(old) => {
                             write!(f, "{}", Colour::Red.paint(old))?;
-                        },
+                        }
                         TextDiff::Unchanged(same) => {
                             write!(f, "{}", same)?;
-                        },
+                        }
                         _ => (),
                     }
                 }
@@ -68,10 +72,10 @@ impl Rename {
                     match change {
                         TextDiff::New(new) => {
                             write!(f, "{}", Colour::Green.paint(new))?;
-                        },
+                        }
                         TextDiff::Unchanged(same) => {
                             write!(f, "{}", same)?;
-                        },
+                        }
                         _ => (),
                     }
                 }
@@ -122,7 +126,7 @@ fn find_renames(
             } else {
                 Some(Rename {
                     original: original.to_string(),
-                    new: new.to_string()
+                    new: new.to_string(),
                 })
             }
         })
@@ -154,7 +158,7 @@ fn get_input(files: Vec<String>) -> anyhow::Result<Vec<String>> {
 fn get_input_files(files: Vec<String>) -> anyhow::Result<Vec<String>> {
     let mut input_files = get_input(files)?;
     // This is a special case where we want to expand `.` and `..`.
-    let dots = vec![".", ".."];
+    let dots = &[".", ".."];
     if input_files.len() == 1 && dots.contains(&input_files[0].as_str()) {
         input_files = expand_dir(&input_files[0])?;
     }
@@ -167,10 +171,10 @@ fn get_input_files(files: Vec<String>) -> anyhow::Result<Vec<String>> {
 
 fn expand_dir(path: &str) -> anyhow::Result<Vec<String>, io::Error> {
     Ok(fs::read_dir(path)?
-        .flatten()
-        .filter_map(|e| e.path()
-                .into_os_string()
-                .into_string().ok())
+        .filter_map(|e| {
+            e.ok()
+                .and_then(|e| e.path().into_os_string().into_string().ok())
+        })
         .collect())
 }
 
@@ -184,7 +188,10 @@ fn open_editor(input_files: &Vec<String>) -> anyhow::Result<Vec<String>> {
         .spawn()
         .context("Failed to execute editor process")?;
 
-    child.wait_with_output()?;
+    let output = child.wait_with_output()?;
+    if !output.status.success() {
+        return Err(anyhow!("Editor terminated unexpectedly. Aborting."));
+    }
 
     Ok(fs::read_to_string(&tmpfile)?
         .lines()
@@ -200,7 +207,7 @@ fn check_for_existing_files(replacements: &Vec<Rename>) -> anyhow::Result<()> {
     if !replacements_over_existing_files.is_empty() {
         println!("The following replacements overwrite existing files:");
         for replacement in &replacements_over_existing_files {
-            println!("{}", Colour::Green.paint(replacement.to_string()));
+            println!("{}", Colour::Red.paint(replacement.to_string()));
         }
         println!();
         return Err(anyhow!("Refusing to overwrite existing files. Aborting."));
@@ -209,6 +216,24 @@ fn check_for_existing_files(replacements: &Vec<Rename>) -> anyhow::Result<()> {
     Ok(())
 }
 
+fn check_input_files(input_files: &Vec<String>) -> anyhow::Result<()> {
+    let nonexisting_files: Vec<_> = input_files
+        .iter()
+        .filter(|input_file| !Path::new(input_file).exists())
+        .collect();
+
+    if !nonexisting_files.is_empty() {
+        println!("The following input files do not exist:");
+        for file in nonexisting_files {
+            println!("{}", Colour::Red.paint(file));
+        }
+        println!();
+        return Err(anyhow!("Nonexisting input files. Aborting."));
+    }
+
+    Ok(())
+}
+
 fn print_replacements(replacements: &Vec<Rename>, pretty: bool) {
     println!(
         "{}",
@@ -231,15 +256,19 @@ fn print_replacements(replacements: &Vec<Rename>, pretty: bool) {
     println!();
 }
 
-fn execute_renames(replacements: &Vec<Rename>, rename_command: Option<String>) -> anyhow::Result<()> {
+fn execute_renames(
+    replacements: &Vec<Rename>,
+    rename_command: Option<String>,
+) -> anyhow::Result<()> {
     for replacement in replacements {
         if let Some(ref cmd) = rename_command {
             subprocess::Exec::shell(format!(
-                    "{} {} {}",
-                    cmd,
-                    escape(Cow::from(replacement.original.clone())),
-                    escape(Cow::from(replacement.new.clone()))
-            )).join()?;
+                "{} {} {}",
+                cmd,
+                escape(Cow::from(replacement.original.clone())),
+                escape(Cow::from(replacement.new.clone()))
+            ))
+            .join()?;
         } else {
             fs::rename(&replacement.original, &replacement.new)?;
         }
@@ -248,11 +277,9 @@ fn execute_renames(replacements: &Vec<Rename>, rename_command: Option<String>) -
     Ok(())
 }
 
-fn prompt(yes: bool) -> anyhow::Result<&'static str> {
-    let selections = vec!["Yes", "No", "Edit", "Reset"];
-
+fn prompt(selections: &[MenuItem], yes: bool) -> anyhow::Result<&MenuItem> {
     if yes {
-        return Ok(selections[0]);
+        return Ok(&selections[0]);
     }
 
     let selection = Select::new()
@@ -261,12 +288,37 @@ fn prompt(yes: bool) -> anyhow::Result<&'static str> {
         .items(&selections)
         .interact()?;
 
-    Ok(selections[selection])
+    Ok(&selections[selection])
+}
+
+enum MenuItem {
+    /// Perform the current replacements
+    Yes,
+    /// Abort and do nothing
+    No,
+    /// Open the editor with the current replacements for edit
+    Edit,
+    /// Open the editor with the original names for edit
+    Reset,
+}
+
+impl Display for MenuItem {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            MenuItem::Yes => f.write_str("Yes"),
+            MenuItem::No => f.write_str("No"),
+            MenuItem::Edit => f.write_str("Edit"),
+            MenuItem::Reset => f.write_str("Reset"),
+        }
+    }
 }
 
 fn main() -> anyhow::Result<()> {
     let opts = Opts::parse();
     let input_files = get_input_files(opts.files)?;
+
+    check_input_files(&input_files)?;
+
     let mut buffer = input_files.clone();
 
     loop {
@@ -274,21 +326,28 @@ fn main() -> anyhow::Result<()> {
         let replacements = find_renames(&input_files, &new_files)?;
         println!();
 
-        check_for_existing_files(&replacements)?;
-        print_replacements(&replacements, opts.pretty_diff);
+        let check_existing = check_for_existing_files(&replacements);
 
-        match prompt(opts.assume_yes)? {
-            "Yes" => {
+        let menu_options = match check_existing {
+            Ok(()) => {
+                print_replacements(&replacements, opts.pretty_diff);
+                vec![MenuItem::Yes, MenuItem::No, MenuItem::Edit, MenuItem::Reset]
+            }
+            e @ Err(_) if opts.assume_yes => return e,
+            Err(_) => vec![MenuItem::Edit, MenuItem::Yes, MenuItem::No, MenuItem::Reset],
+        };
+
+        match prompt(&menu_options, opts.assume_yes)? {
+            MenuItem::Yes => {
                 execute_renames(&replacements, opts.rename_command)?;
                 break;
-            },
-            "No" => {
+            }
+            MenuItem::No => {
                 println!("Aborting");
                 break;
-            },
-            "Edit" => buffer = new_files.clone(),
-            "Reset" => buffer = input_files.clone(),
-            _ => unreachable!(),
+            }
+            MenuItem::Edit => buffer = new_files.clone(),
+            MenuItem::Reset => buffer = input_files.clone(),
         }
     }
 
